# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
import typing_extensions
import typing_extensions
import typing
from ..types.catalog_modifier_list_selection_type import CatalogModifierListSelectionType
from ..types.catalog_modifier_list_modifier_type import CatalogModifierListModifierType
import typing

if typing.TYPE_CHECKING:
    from .catalog_object import CatalogObjectParams


class CatalogModifierListParams(typing_extensions.TypedDict):
    """
    For a text-based modifier, this encapsulates the modifier's text when its `modifier_type` is `TEXT`.
    For example, to sell T-shirts with custom prints, a text-based modifier can be used to capture the buyer-supplied
    text string to be selected for the T-shirt at the time of sale.

    For non text-based modifiers, this encapsulates a non-empty list of modifiers applicable to items
    at the time of sale. Each element of the modifier list is a `CatalogObject` instance of the `MODIFIER` type.
    For example, a "Condiments" modifier list applicable to a "Hot Dog" item
    may contain "Ketchup", "Mustard", and "Relish" modifiers.

    A non text-based modifier can be applied to the modified item once or multiple times, if the `selection_type` field
    is set to `SINGLE` or `MULTIPLE`, respectively. On the other hand, a text-based modifier can be applied to the item
    only once and the `selection_type` field is always set to `SINGLE`.
    """

    name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    The name of the `CatalogModifierList` instance. This is a searchable attribute for use in applicable query filters, and its value length is of 
    Unicode code points.
    """

    ordinal: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The position of this `CatalogModifierList` within a list of `CatalogModifierList` instances.
    """

    selection_type: typing_extensions.NotRequired[CatalogModifierListSelectionType]
    """
    Indicates whether a single (`SINGLE`) or multiple (`MULTIPLE`) modifiers from the list
    can be applied to a single `CatalogItem`.
    
    For text-based modifiers, the `selection_type` attribute is always `SINGLE`. The other value is ignored.
    See [CatalogModifierListSelectionType](#type-catalogmodifierlistselectiontype) for possible values
    """

    modifiers: typing_extensions.NotRequired[typing.Optional[typing.Sequence["CatalogObjectParams"]]]
    """
    A non-empty list of `CatalogModifier` objects to be included in the `CatalogModifierList`, 
    for non text-based modifiers when the `modifier_type` attribute is `LIST`. Each element of this list 
    is a `CatalogObject` instance of the `MODIFIER` type, containing the following attributes:
    ```
    {
    "id": "{{catalog_modifier_id}}",
    "type": "MODIFIER", 
    "modifier_data": {{a CatalogModifier instance>}} 
    }
    ```
    """

    image_ids: typing_extensions.NotRequired[typing.Optional[typing.Sequence[str]]]
    """
    The IDs of images associated with this `CatalogModifierList` instance.
    Currently these images are not displayed on Square products, but may be displayed in 3rd-party applications.
    """

    modifier_type: typing_extensions.NotRequired[CatalogModifierListModifierType]
    """
    The type of the modifier. 
    
    When this `modifier_type` value is `TEXT`,  the `CatalogModifierList` represents a text-based modifier. 
    When this `modifier_type` value is `LIST`, the `CatalogModifierList` contains a list of `CatalogModifier` objects.
    See [CatalogModifierListModifierType](#type-catalogmodifierlistmodifiertype) for possible values
    """

    max_length: typing_extensions.NotRequired[typing.Optional[int]]
    """
    The maximum length, in Unicode points, of the text string of the text-based modifier as represented by 
    this `CatalogModifierList` object with the `modifier_type` set to `TEXT`.
    """

    text_required: typing_extensions.NotRequired[typing.Optional[bool]]
    """
    Whether the text string must be a non-empty string (`true`) or not (`false`) for a text-based modifier
    as represented by this `CatalogModifierList` object with the `modifier_type` set to `TEXT`.
    """

    internal_name: typing_extensions.NotRequired[typing.Optional[str]]
    """
    A note for internal use by the business.   
    
    For example, for a text-based modifier applied to a T-shirt item, if the buyer-supplied text of "Hello, Kitty!"  
    is to be printed on the T-shirt, this `internal_name` attribute can be "Use italic face" as 
    an instruction for the business to follow.  
    
    For non text-based modifiers, this `internal_name` attribute can be 
    used to include SKUs, internal codes, or supplemental descriptions for internal use.
    """
